==> 0.0.29.tar.gz: lib/model/app_info.dart <==
part of trober_sdk.api;

// AppInfo
class AppInfo {
  String currentVersion;

  String minVersion;
  AppInfo();

  @override
  String toString() {
    return 'AppInfo[currentVersion=$currentVersion, minVersion=$minVersion, ]';
  }

  fromJson(Map<String, dynamic> json) {
    if (json == null) return;

    {
      final _jsonData = json[r'currentVersion'];
      currentVersion = (_jsonData == null) ? null : _jsonData;
    } // _jsonFieldName
    {
      final _jsonData = json[r'minVersion'];
      minVersion = (_jsonData == null) ? null : _jsonData;
    } // _jsonFieldName
  }

  AppInfo.fromJson(Map<String, dynamic> json) {
    fromJson(json); // allows child classes to call
  }

  Map<String, dynamic> toJson() {
    final json = <String, dynamic>{};
    if (currentVersion != null) {
      json[r'currentVersion'] = LocalApiClient.serialize(currentVersion);
    }
    if (minVersion != null) {
      json[r'minVersion'] = LocalApiClient.serialize(minVersion);
    }
    return json;
  }

  static List<AppInfo> listFromJson(List<dynamic> json) {
    return json == null
        ? <AppInfo>[]
        : json.map((value) => AppInfo.fromJson(value)).toList();
  }

  static Map<String, AppInfo> mapFromJson(Map<String, dynamic> json) {
    final map = <String, AppInfo>{};
    if (json != null && json.isNotEmpty) {
      json.forEach(
          (String key, dynamic value) => map[key] = AppInfo.fromJson(value));
    }
    return map;
  }

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is AppInfo && runtimeType == other.runtimeType) {
      return currentVersion == other.currentVersion &&
          minVersion == other.minVersion;
    }

    return false;
  }

  @override
  int get hashCode {
    var hashCode = runtimeType.hashCode;

    if (currentVersion != null) {
      hashCode = hashCode ^ currentVersion.hashCode;
    }

    if (minVersion != null) {
      hashCode = hashCode ^ minVersion.hashCode;
    }

    return hashCode;
  }

  AppInfo copyWith({
    String currentVersion,
    String minVersion,
  }) {
    AppInfo copy = AppInfo();
    copy.currentVersion = currentVersion ?? this.currentVersion;
    copy.minVersion = minVersion ?? this.minVersion;
    return copy;
  }
}

==> 0.0.42.tar.gz: lib/model/app_info.dart <==
part of trober_sdk.api;

// AppInfo
class AppInfo {
  String minVersion;
  AppInfo();

  @override
  String toString() {
    return 'AppInfo[minVersion=$minVersion, ]';
  }

  fromJson(Map<String, dynamic> json) {
    if (json == null) return;

    {
      final _jsonData = json[r'minVersion'];
      minVersion = (_jsonData == null) ? null : _jsonData;
    } // _jsonFieldName
  }

  AppInfo.fromJson(Map<String, dynamic> json) {
    fromJson(json); // allows child classes to call
  }

  Map<String, dynamic> toJson() {
    final json = <String, dynamic>{};
    if (minVersion != null) {
      json[r'minVersion'] = LocalApiClient.serialize(minVersion);
    }
    return json;
  }

  static List<AppInfo> listFromJson(List<dynamic> json) {
    return json == null
        ? <AppInfo>[]
        : json.map((value) => AppInfo.fromJson(value)).toList();
  }

  static Map<String, AppInfo> mapFromJson(Map<String, dynamic> json) {
    final map = <String, AppInfo>{};
    if (json != null && json.isNotEmpty) {
      json.forEach(
          (String key, dynamic value) => map[key] = AppInfo.fromJson(value));
    }
    return map;
  }

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is AppInfo && runtimeType == other.runtimeType) {
      return minVersion == other.minVersion;
    }

    return false;
  }

  @override
  int get hashCode {
    var hashCode = runtimeType.hashCode;

    if (minVersion != null) {
      hashCode = hashCode ^ minVersion.hashCode;
    }

    return hashCode;
  }

  AppInfo copyWith({
    String minVersion,
  }) {
    AppInfo copy = AppInfo();
    copy.minVersion = minVersion ?? this.minVersion;
    return copy;
  }
}
